@@ -117,8 +117,12 @@ class Table(object):
         they will be created based on the settings of ``ensure`` and
         ``types``, matching the behavior of :py:meth:`insert() <dataset.Table.insert>`.
         """
+        # check whether keys arg is a string and format as a list
+        if isinstance(keys, basestring):
+            keys = [keys]
+            
         self._check_dropped()
-        if not len(keys):
+        if not len(keys) or len(keys)==len(row):
             return False
         clause = [(u, row.get(u)) for u in keys]
         """
@@ -147,6 +151,10 @@ class Table(object):
             data = dict(id=10, title='I am a banana!')
             table.upsert(data, ['id'])
         """
+        # check whether keys arg is a string and format as a list
+        if isinstance(keys, basestring):
+            keys = [keys]
+            
         self._check_dropped()
         if ensure:
             self.create_index(keys)
@@ -244,7 +252,7 @@ class Table(object):
 
     def find_one(self, **_filter):
         """
-        Works just like :py:meth:`find() <dataset.Table.find>` but returns only one result.
+        Works just like :py:meth:`find() <dataset.Table.find>` but returns one result, or None.
         ::
 
             row = table.find_one(country='United States')
