@@ -1,3 +1,4 @@
+import os
 import unittest
 from datetime import datetime
 
@@ -9,11 +10,19 @@ from sample_data import TEST_DATA
 class DatabaseTestCase(unittest.TestCase):
 
     def setUp(self):
-        self.db = connect('sqlite:///:memory:')
+        os.environ['DATABASE_URL'] = 'sqlite:///:memory:'
+        self.db = connect()
         self.tbl = self.db['weather']
         for row in TEST_DATA:
             self.tbl.insert(row)
 
+    def tearDown(self):
+        # ensure env variable was unset
+        del os.environ['DATABASE_URL']
+
+    def test_valid_database_url(self):
+        assert self.db.url, os.environ['DATABASE_URL']
+
     def test_tables(self):
         assert self.db.tables == ['weather'], self.db.tables
 
@@ -66,6 +75,15 @@ class TableTestCase(unittest.TestCase):
         )
         assert len(self.tbl) == len(TEST_DATA)+1, len(self.tbl)
 
+    def test_upsert_all_key(self):
+        for i in range(0,2):
+            self.tbl.upsert({
+                'date': datetime(2011, 01, 02),
+                'temperature': -10,
+                'place': 'Berlin'},
+                ['date', 'temperature', 'place']
+            )
+
     def test_delete(self):
         self.tbl.insert({
             'date': datetime(2011, 01, 02),
